@@ -168,7 +168,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-	printf("astime : AfterStep analog clock version 2.7\n");
+	printf("astime : AfterStep analog clock version 2.8\n");
 }
 
 /* parse the rc file */
@@ -265,8 +265,10 @@ void parsercfile(FILE * ifp)
 					state.label_top = 1;
 			} else if (!strcmp(param[0], "drawSecondHand")) {
 				tval = atoi(param[1]);
-				if (tval)
-					state.draw_seconds = atoi(param[1]);
+				if (tval == 0)
+					state.draw_seconds = 0;
+				else
+					state.draw_seconds = 1;
 			} else if (!strcmp(param[0], "drawDayDate")) {
 				tval = atoi(param[1]);
 				if (tval == 0)
