@@ -623,7 +623,8 @@ void initialize(int argc, char **argv,
 		char *mainGeometry,
 		int withdrawn,
 		int iconic,
-		int pushed_in)
+		int pushed_in,
+		int no_border)
 {
 	int screen;
 	Status status;
@@ -986,6 +987,9 @@ void initialize(int argc, char **argv,
 		       state.total_size.x,
 		       state.total_size.y
 	    );
+
+      if (!no_border) {
+	
 	/* The shadow on the sides */
 	if (pushed_in) {
 		tmp_pix = DarkenColor(state.bgcolor, 1.6, mainDisplay, Root);
@@ -1041,7 +1045,8 @@ void initialize(int argc, char **argv,
 		  0,
 		  state.total_size.y - 1
 	    );
-
+      }
+      
 	/* Finish up the background (the dial) */
 	draw_dial();
 
