@@ -17,7 +17,8 @@ void initialize(int argc, char **argv,
                 char *mainGeometry,
                 int withdrawn,
                 int iconic,
-                int pushed_in);
+                int pushed_in,
+		int no_border);
 void update();
 void redraw();
 void x_cleanup();
