@@ -1,10 +1,10 @@
 /*
  * astime is an analogue clock utility for X Windows.
  *
- * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
+ * Copyright (c) 1998-2000  Albert Dorofeev <albert@tigr.net>
  * Copyright (c) 1999 William Kostis <kostis@ee.cornell.edu>
  *
- * For the updates see http://bewoner.dma.be/Albert/afterstep/
+ * For the updates see http://www.tigr.net/afterstep/as-apps/
  *
  * This software is distributed under GPL. For details see LICENSE file.
  */
@@ -85,7 +85,7 @@ struct astime_state {
 
   int nprogs;
   /* program parameters */
-  PInfo *PI;
+  PInfo *PInf;
 };
 
 #endif
